#!/bin/bash
#
#
# Parses DHCP options from openvpn to update DNS and Domains
#
# Used snippets of resolvconf script by Thomas Hood and Chris Hanson.
# Licensed under the GNU GPL.  See /usr/share/common-licenses/GPL.
#
# Example envs set from openvpn:
#
#     foreign_option_1='dhcp-option DNS 193.43.27.132'
#     foreign_option_2='dhcp-option DNS 193.43.27.133'
#     foreign_option_3='dhcp-option DOMAIN be.bnc.ch'
#
# Set as up.sh script for User-Defined VPN connections.
#
# Gijs Withagen, 19-3-2020
#
# Alexey Pronin, 25-3-2020

NMSRVRS=""
SRCHS=""

for optionvarname in $(set | awk -F "=" '{print $1}' | grep foreign_option_); do

        eval option=\$$optionvarname
        echo $option

        part1=$(echo "$option" | cut -d " " -f 1)
        if [ "$part1" == "dhcp-option" ] ; then
            part2=$(echo "$option" | cut -d " " -f 2)
            part3=$(echo "$option" | cut -d " " -f 3)
        fi
        echo $part1
        echo $part2
        echo $part3

        if [ "$part1" = "dhcp-option" ] ; then
                if [ "$part2" = "DNS" ] ; then
                        NMSRVRS="${NMSRVRS:+$NMSRVRS }$part3"
                elif [ "$part2" = "DOMAIN" ] ; then
                        SRCHS="${SRCHS:+$SRCHS }$part3"
                fi
        fi
done
echo "$NMSRVRS"

cat /etc/resolv.conf | grep "nameserver" | awk '{print $2}' > /storage/.config/openvpn/nameservers.bak

while read DNS; do
    NMSRVRS="${NMSRVRS:+$NMSRVRS }$DNS"
done < /storage/.config/openvpn/nameservers.bak
echo "$NMSRVRS"

ETHSVC=$(connmanctl services | awk '{print $3}')
echo "$ETHSVC"

connmanctl config "$ETHSVC" --nameservers "$NMSRVRS"
#
# have to remove routes to DNS server that connmanctl makes
#
for ns in $NMSRVRS ; do
  /sbin/ip route del $ns
  echo "removed route $ns"
done

connmanctl config "$ETHSVC" --domains "$SRCHS"
